#
# spec file for package miniupnpc
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soname 17
Name:           miniupnpc
Version:        2.2.6
Release:        1.4
Summary:        Universal Plug'n'Play (UPnP) Client
License:        BSD-3-Clause
Group:          Productivity/Networking/Other
URL:            http://miniupnp.free.fr/
Source:         http://miniupnp.free.fr/files/miniupnpc-%{version}.tar.gz
Source2:        http://miniupnp.free.fr/files/miniupnpc-%{version}.tar.gz.sig
Source3:        http://miniupnp.free.fr/A31ACAAF.asc#/%{name}.keyring
Source99:       baselibs.conf
# PATCH-FIX-SUSE: do not hardcode kernel version in headers
Patch0:         miniupnpc-kernelversion.patch
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
Requires:       libminiupnpc%{soname} = %{version}-%{release}

%if 0%{?suse_version} >= 1550
# TW: generate subpackages for every python3 flavor
%define python_subpackage_only 1
%python_subpackages
%else
# same "defaults" for all distributions, used in %files below
%define python_files() -n python3-%{**}
%define python_sitearch %{python3_sitearch}
%endif

%description
The MiniUPnP project offers software which supports the UPnP Internet Gateway
Device (IGD) specifications.

%package -n libminiupnpc%{soname}
Summary:        Universal Plug'n'Play (UPnP) Client Library
Group:          System/Libraries

%description -n libminiupnpc%{soname}
The MiniUPnP project offers software which supports the UPnP Internet Gateway
Device (IGD) specifications.

%package -n libminiupnpc-devel
Summary:        Universal Plug'n'Play (UPnP) Client Library
Group:          Development/Libraries/C and C++
Requires:       libminiupnpc%{soname} = %{version}-%{release}

%description -n libminiupnpc-devel
The MiniUPnP project offers software which supports the UPnP Internet Gateway
Device (IGD) specifications.

%if 0%{?python_subpackage_only}
%package -n python-miniupnpc
Summary:        Universal Plug'n'Play (UPnP) Client Module for Python
Group:          Development/Libraries/Python
Requires:       libminiupnpc%{soname} = %{version}-%{release}

%description -n python-miniupnpc
The MiniUPnP project offers software which supports the UPnP Internet Gateway
Device (IGD) specifications.

%else

%package -n python3-miniupnpc
Summary:        Universal Plug'n'Play (UPnP) Client Module for Python
Group:          Development/Libraries/Python
Requires:       libminiupnpc%{soname} = %{version}-%{release}

%description -n python3-miniupnpc
The MiniUPnP project offers software which supports the UPnP Internet Gateway
Device (IGD) specifications.
%endif

%prep
%autosetup -p1

%build
export CFLAGS="%{optflags}"
%make_build \
     CC="gcc" BUILD=$PWD/build \
     OPTFLAGS="%{optflags}" \
     PYTHON="python3"

%python_build

%install
%make_install INSTALLDIRLIB=%{_libdir} LIBDIR=%{_lib}

%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}
# Remove static libs
rm -f %{buildroot}%{_libdir}/*.a
# The man page should be non executable
chmod -x %{buildroot}%{_mandir}/man3/miniupnpc.3.gz

%post   -n libminiupnpc%{soname} -p /sbin/ldconfig
%postun -n libminiupnpc%{soname} -p /sbin/ldconfig

%check
%make_build test

%files
%{_bindir}/upnpc
%{_bindir}/external-ip
%{_bindir}/upnp-listdevices
%{_mandir}/man3/miniupnpc.3%{?ext_man}

%files -n libminiupnpc%{soname}
%doc Changelog.txt README
%license LICENSE
%{_libdir}/libminiupnpc.so.%{soname}

%files -n libminiupnpc-devel
%{_includedir}/miniupnpc/
%{_libdir}/libminiupnpc.so
%{_libdir}/pkgconfig/miniupnpc.pc

%files %{python_files miniupnpc}
%doc Changelog.txt README
%license LICENSE
%{python_sitearch}/miniupnpc*

%changelog
* Sun Apr  7 2024 Andrea Manzini <andrea.manzini@suse.com>
- update to 2.2.6:
  * includes charset="utf-8" in Content-Type
  * fix memory allocation error in minissdpc.c
  * Make User-Agent compliant.
  * add new binary listdevices => upnp-listdevices
- added %%check section to run unit tests
* Sat Jul 15 2023 Dirk Müller <dmueller@suse.com>
- update to 2.2.5:
  * GetListOfPortMappings NewStartPort 0 => 1
  * CheckPinholeWorking is optional
  * add 60x errors from UPnP Device Architecture
  * cmake: install binaries, man pages and external-ip.sh
- drop python2 support
* Fri Dec 23 2022 Dirk Müller <dmueller@suse.com>
- update to 2.2.4:
  * upnpc: use of @ to replace local lan address
  * python module : Allow to specify the root description url
  * Change directory structure : include/ and src/ directories.
- drop makefile-deps-fix.patch (upstream)
* Thu Jun  9 2022 Martin Hauke <mardnh@gmx.de>
- Set LIBIR during 'make install' to fix the library path in the
  generated pkg-config file.
* Tue May 18 2021 Andreas Stieger <andreas.stieger@gmx.de>
- add upstream signing key and validate source signature
* Wed Apr 28 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 2.2.2:
  * miniupnpcmodule.c: throw an exception in UPnP_discover()
  * Fix usage of IP_MULTICAST_IF with struct ip_mreqn
* Thu Mar 25 2021 Ben Greiner <code@bnavigator.de>
- Can't assume non-existence of python38 macros in Leap.
  gh#openSUSE/python-rpm-macros#107
  Test for suse_version instead. Only Tumbleweed has and needs the
  python_subpackage_only support.
* Tue Dec 29 2020 Dirk Müller <dmueller@suse.com>
- update to 2.2.1:
  * Add miniupnpc.rc for .dll description
  * Check properly for reserved IP addresses
  * prevent infinite loop in upnpDiscover()
  * Add Haiku support
  * testminiwget.sh can use either "ip addr" or "ifconfig -a
  * fix UPNP_GetValidIGD() when several devices are found
  * Allow Remote Host on upnpc command line
  * fix error 708 description in strupnperror()
  * Fix memory leak in upnpreplyparse.c with NewPortListing element
  * connecthostport.c: Code simplification, error trace fix
  * set timeout for select() in connecthostport()
  * miniupnpcmodule.c: check return of WSAStartup()
* Sun Nov 22 2020 Benjamin Greiner <code@bnavigator.de>
- Fix the python subpackage generation
  gh#openSUSE/python-rpm-macros#79
* Sat Nov 14 2020 Benjamin Greiner <code@bnavigator.de>
- Support multiple python3 flavors gh#openSUSE/python-rpm-macros#66
- Don't own the whole python sitearch directory
* Wed Sep  5 2018 joop.boonen@opensuse.org
- Version 2.1 solved:
  * CVE-2017-1000494: https://github.com/miniupnp/miniupnp/issues/268 https://github.com/miniupnp/miniupnp/commit/7aeb624b44f86d335841242ff427433190e7168a
  * bnc#1075137 - (CVE-2017-1000494) VUL-1: CVE-2017-1000494 miniupnpc: Multiple vulnerabilities can allow a remote attacker to cause a denial of service or potentially execute code
* Fri Jun 29 2018 tchvatal@suse.com
- Fix reproducability by not coding in kernel version:
  * miniupnpc-kernelversion.patch
- Fix build with python3 only present in system
* Sat May 26 2018 joop.boonen@opensuse.org
- Build 2.1
  * CMake Modernize and cleanup CMakeLists.txt
  * Update MS Visual Studio projects
    listdevices: show devices sorted by XML desc URL
  * Small fix in miniupnpcmodule.c (python module)
  * Support cross compiling in Makefile.mingw
  * Use SOCKET type instead of int (for Win64 compilation)
  * Increments API_VERSION to 17
  * Disable usage of MiniSSDPd when using -m option
  * Fix buffer over run in minixml.c
  * Fix uninitialized variable access in upnpreplyparse.c
* Mon Nov  6 2017 joop.boonen@opensuse.org
- Build 2.0.20171102
  * Fix CVE-2017-8798   Thanks to tin/Team OSTStrom
  * bnc#1038601 - (CVE-2017-8798) VUL-0: CVE-2017-8798: miniupnp: integer signedness error
* Tue May 23 2017 joop.boonen@opensuse.org
- Build 2.0.20170509
  * Fix CVE-2017-8798 Thanks to tin/Team OSTStrom
  * bnc#1038601 fixes VUL-0: CVE-2017-8798: miniupnp: integer signedness error
* Sun Apr 24 2016 idonmez@suse.com
- Update to version 2.0
  * No code changes since 1.9.20160209
* Sat Feb 20 2016 mpluskal@suse.com
- Update to 1.9.20160209
  * change miniwget to return HTTP status code
  * increments API_VERSION to 16
  * Improve UPNPIGD_IsConnected() to check if WAN address is not
    private. parse HTTP response status line in miniwget.c
* Tue Nov 17 2015 mpluskal@suse.com
- Update to 1.9.20151026
  * snprintf() overflow check. check overflow in simpleUPnPcommand2()
  * fix compilation with old macs
  * fix compilation with mingw32 (for Appveyor)
  * fix python module for python <= 2.3
  * Change sameport to localport
    see https://github.com/miniupnp/miniupnp/pull/120
  * increments API_VERSION to 15
  * Fix buffer overflow in igd_desc_parse.c/IGDstartelt()
    Discovered by Aleksandar Nikolic of Cisco Talos
  * move ssdpDiscoverDevices() to minissdpc.c
  * avoid unix socket leak in getDevicesFromMiniSSDPD()
  * Also accept "Up" as ConnectionStatus value
  * split getDevicesFromMiniSSDPD
  * add ttl argument to upnpDiscover() functions
  * increments API_VERSION to 14
  * Read USN from SSDP messages.
  * Check malloc/calloc
  * update getDevicesFromMiniSSDPD() to process longer minissdpd
    responses
  * add searchalltypes param to upnpDiscoverDevices()
  * increments API_VERSION to 13
  * upnpc: output version on the terminal
    _BSD_SOURCE is deprecated in favor of _DEFAULT_SOURCE
  * fix CMakeLists.txt COMPILE_DEFINITIONS
  * fix getDevicesFromMiniSSDPD() not setting scope_id
  * improve -r command of upnpc command line tool
  * search all :
    upnpDiscoverDevices() / upnpDiscoverAll() functions
    listdevices executable
  * increment API_VERSION to 12
  * validate igd_desc_parse
  * increment API_VERSION to 11
  simplified function GetUPNPUrls()
  * use remoteHost arg of DeletePortMapping
  * Fix python3 build
  * Fix parsing of IGD2 root descriptions
  * rename LIBSPEC to MINIUPNP_LIBSPEC
  * Add support for IGD2 AddAnyPortMapping and DeletePortMappingRange
  * handle EINPROGRESS after connect()
  * minixml now handle XML comments
* Wed Jul 29 2015 dimstar@opensuse.org
- Add baselibs.conf: build libminiupnpc10-32bit, as needed by
  libsocks0-32bit.
* Wed Jun 11 2014 joop.boonen@opensuse.org
- Update to 1.9:
  * added argument remoteHost to UPNP_GetSpecificPortMappingEntry()
    increment API_VERSION to 10
  * --help and -h arguments in upnpc.c
  * fixed potential buffer overrun in miniwget.c
    bnc#881990
    CVE-2014-3985
    Modified UPNP_GetValidIGD() to check for ExternalIpAddress
  * define MAXHOSTNAMELEN if not already done
  * update upnpreplyparse to allow larger values (128 chars instead of 64)
  * Update upnpreplyparse to take into account "empty" elements
    validate upnpreplyparse.c code with "make check"
  * Fix Solaris build thanks to Maciej Małecki
  * Fix testminiwget.sh for BSD
  * Fixed Makefile for *BSD
  * Update Makefile to use JNAerator version 0.11
  * Fix testminiwget.sh for use with dash
    Use $(DESTDIR) in Makefile
- Use optflags for building
* Thu Jun  6 2013 joop.boonen@opensuse.org
- Update to 1.8:
  * fix testminiwget with no IPv6 support
  * Rename all include guards to not clash with C99
    (7.1.3 Reserved identifiers).
  * Added -e option to upnpc program (set description for port mappings)
  * Python 3 support (thanks to Christopher Foo)
  * Fix a memory link in UPNP_GetValidIGD()
  * Try to handle scope id in link local IPv6 URL under MS Windows
  * Disable HAS_IP_MREQN on DragonFly BSD
  * GetUPNPUrls() now inserts scope into link-local IPv6 addresses
  * More error return checks in upnpc.c
    [#]define MINIUPNPC_GET_SRC_ADDR enables receivedata() to get scope_id
  * parseURL() now parses IPv6 addresses scope
  * new parameter for miniwget() : IPv6 address scope
  * increment API_VERSION to 9
  * fixed CMakeLists.txt
  * Improvements in testminiwget.sh
* Mon Dec 24 2012 p.drouand@gmail.com
- Update to 1.7 version:
  * Cleanup settings of CFLAGS in Makefile
  * Fix signed/unsigned integer comparaisons
  * Allow to specify protocol with TCP or UDP for -A option
  * Only try to fetch XML description once in UPNP_GetValidIGD()
  * Added -ansi flag to compilation, and fixed C++ comments to ANSI C comments.
  * minor improvements to minihttptestserver.c
  * upnperrors.c returns valid error string for unrecognized error codes
  * make minihttptestserver listen on loopback interface instead of 0.0.0.0
  * Maven installation thanks to Alexey Kuznetsov
  * Replace WIN32 macro by _WIN32
  * Fixes in java wrappers thanks to Alexey Kuznetsov :
    https://github.com/axet/miniupnp/tree/fix-javatest/miniupnpc
  * Make and install .deb packages (python) thanks to Alexey Kuznetsov :
    https://github.com/axet/miniupnp/tree/feature-debbuild/miniupnpc
  * The multicast interface can now be specified by name with IPv4.
  * Install man page
  * added header to Port Mappings list in upnpc.c
  * Makefile : make clean now removes jnaerator generated files.
  * MINIUPNPC_VERSION in miniupnpc.h (updated by make)
  * added rootdescURL to UPNPUrls structure.
- Remove unneeded miniupnpc-makefile.patch
* Fri Feb 17 2012 vuntz@opensuse.org
- Install the headers in /usr/include/miniupnpc/ instead of
  /usr/include/: this is cleaner, and this is what users of the
  library expect.
* Sat Jan  7 2012 joop.boonen@opensuse.org
- Corrected the License
* Fri Dec 23 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
- Use %%_smp_mflags for parallel building
* Fri Dec 23 2011 joop.boonen@opensuse.org
- Build version 1.6
- soname 5 -> 8
* Wed Mar  9 2011 pascal.bleser@opensuse.org
- soname 4 -> 5
- update to 1.5
* Sun Mar  7 2010 pascal@links2linux.de
- initial package
